==> phpunit_9.6.15.orig.tar.xz: phpunit-9.6.15/.github/ISSUE_TEMPLATE/1_BUG.md <==
---
name: 🐞 Bug Report for PHPUnit 9 and PHPUnit 10
about: Something is broken in PHPUnit 9 and in PHPUnit 10?
labels: type/bug, version/9, version/10
---

<!--
- Please do not report an issue for a version of PHPUnit that is no longer supported. A list of currently supported versions of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are using a version of PHP that is not supported by the version of PHPUnit you are using. A list that shows which version of PHP is supported by which version of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are not using PHPUnit directly, but rather a third-party wrapper around it.
- Please do not report an issue if you are using a third-party extension such as alternative output printers.
- Please do not report an issue for API changes in internal code (see https://phpunit.de/backward-compatibility.html#internal-code).
- Please fill in this template according to your issue.
- Please keep the table shown below at the top of your issue.
- Please include the output of "composer info | sort" if you installed PHPUnit using Composer.
- Please post code as text (using proper markup). Do not post screenshots of code.
- Please make sure that you have configured your PHP interpreter like so: `error_reporting=-1`, `log_errors_max_len=0`, `zend.assertions=1`, `assert.exception=1`.
- Please remove this comment before submitting your issue.
-->

| Q                   | A
| --------------------| ---------------
| PHPUnit version     | x.y.z
| PHP version         | x.y.z
| Installation Method | Composer / PHAR

#### Summary

<!-- Provide a summary describing the problem you are experiencing. -->

#### Current behavior

<!-- What is the current (buggy) behavior? -->

#### How to reproduce

<!-- Provide steps to reproduce the bug. -->

#### Expected behavior

<!-- What was the expected (correct) behavior? -->

==> phpunit_9.6.17.orig.tar.xz: phpunit-9.6.17/.github/ISSUE_TEMPLATE/1_BUG.md <==
---
name: 🐞 Bug Report
about: Something is broken?
labels: type/bug
---

<!--
- Please do not report a bug for a version of PHPUnit that is no longer in Bugfix Support. A list of currently supported versions of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are using a version of PHP that is not supported by the version of PHPUnit you are using. A list that shows which version of PHP is supported by which version of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are not using PHPUnit directly, but rather a third-party wrapper around it.
- Please do not report an issue if you are using a third-party extension such as alternative output printers.
- Please do not report an issue for API changes in internal code (see https://phpunit.de/backward-compatibility.html#internal-code).
- Please fill in this template according to your issue.
- Please keep the table shown below at the top of your issue.
- Please include the output of "composer info | sort" if you installed PHPUnit using Composer.
- Please post code as text (using proper markup). Do not post screenshots of code.
- Please make sure that you have configured your PHP interpreter like so: `error_reporting=-1`, `log_errors_max_len=0`, `zend.assertions=1`, `assert.exception=1`.
- Please remove this comment before submitting your issue.
-->

| Q                   | A
| --------------------| ---------------
| PHPUnit version     | x.y.z
| PHP version         | x.y.z
| Installation Method | Composer / PHAR

#### Summary

<!-- Provide a summary describing the problem you are experiencing. -->

#### Current behavior

<!-- What is the current (buggy) behavior? -->

#### How to reproduce

<!-- Provide steps to reproduce the bug. -->

#### Expected behavior

<!-- What was the expected (correct) behavior? -->
